"""
Arifi-01 Protocol Runner
========================

Implementasi PROTOKOL FONDASI: MATRIKS KETERIKATAN Arifi-01

Dibuat oleh Dr. Profesor Arifi Razzaq (GitHub: razzaqinspires, PyPI: arzzq)
"""

from .arifi_protocol_runner import main, generate_code, analyze_code, evolution_step

__all__ = [
    "main",
    "generate_code",
    "analyze_code",
    "evolution_step",
]

__version__ = "0.1.0"
__author__ = "Dr. Profesor Arifi Razzaq"